@@ -1,3 +1,4 @@
+# coding: utf-8
 from unittest import main, TestCase
 from django.http import HttpRequest
 from django.template.base import Template
@@ -114,5 +115,33 @@ class LessTestCase(TestCase):
 }"""
         self.assertEquals(compiled_content, compiled)
 
+    def test_non_ascii_content(self):
+
+        template = Template("""
+        {% load less %}
+        {% less "styles/non-ascii.less" %}
+        """)
+        compiled_filename = template.render(self._get_request_context()).strip()
+        compiled_path = os.path.join(self.django_settings.STATIC_ROOT, compiled_filename)
+        compiled_content = open(compiled_path).read().strip()
+        compiled = """.external_link:first-child:before {
+  content: "Zobacz także:";
+}"""
+        self.assertEquals(compiled_content, compiled)
+
+    def test_imports(self):
+
+        template = Template("""
+        {% load less %}
+        {% less "styles/import.less" %}
+        """)
+        compiled_filename = template.render(self._get_request_context()).strip()
+        compiled_path = os.path.join(self.django_settings.STATIC_ROOT, compiled_filename)
+        compiled_content = open(compiled_path).read().strip()
+        compiled = """h1 {
+  color: red;
+}"""
+        self.assertEquals(compiled_content, compiled)
+
 if __name__ == '__main__':
     main()
